from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, Boolean, File, String

Pirs_Simulate_V0_1_0 = CommandToolBuilder(tool="pirs_simulate", base_command=["pirs", "simulate"], inputs=[ToolInput(tag="in_read_len", input_type=Int(optional=True), prefix="--read-len", doc=InputDocumentation(doc="Generate reads having a length of LEN.  Default: 100")), ToolInput(tag="in_coverage", input_type=Int(optional=True), prefix="--coverage", doc=InputDocumentation(doc="Set the average sequencing coverage (sometimes called depth).\nIt may be either a floating-point number or an integer.")), ToolInput(tag="in_insert_len_mean", input_type=Int(optional=True), prefix="--insert-len-mean", doc=InputDocumentation(doc="Generate inserts (fragments) having an average length of LEN.\nDefault: 180")), ToolInput(tag="in_insert_len_sd", input_type=Int(optional=True), prefix="--insert-len-sd", doc=InputDocumentation(doc="Set the standard deviation of the insert (fragment) length.\nDefault: 10% of insert length mean.")), ToolInput(tag="in_cyclic_ize", input_type=Boolean(optional=True), prefix="--cyclicize", doc=InputDocumentation(doc="Make the paired-end reads face away from either other, as\nin a jumping library.  Default: the reads face towards each\nother.")), ToolInput(tag="in_diploid", input_type=Boolean(optional=True), prefix="--diploid", doc=InputDocumentation(doc="This option asserts that reads are being simulated from a\ndiploid genome.  It causes the program to abort if there\nare not exactly two reference sequences; in addition, the\ncoverage is divided in half, since the two reference\nsequences are in reality the same genome.  This option\nis not required to simulate diploid reads, but you must\nset the coverage correctly otherwise (it will be half\nas much as you think).")), ToolInput(tag="in_base_calling_profile", input_type=File(optional=True), prefix="--base-calling-profile", doc=InputDocumentation(doc="Use FILE as the base-calling profile.  This profile will be\nused to simulate substitution errors.  Default:\n/usr/local/share/pirs/Base-Calling_Profiles/humNew.PE100.matrix.gz")), ToolInput(tag="in_in_del_error_profile", input_type=File(optional=True), prefix="--indel-error-profile", doc=InputDocumentation(doc="Use FILE as the indel-error profile.  This profile will be\nused to simulate insertions and deletions in the reads that\nare artifacts of the sequencing process.  Default:\n/usr/local/share/pirs/InDel_Profiles/phixv2.InDel.matrix")), ToolInput(tag="in_gc_content_bias_profile", input_type=File(optional=True), prefix="--gc-content-bias-profile", doc=InputDocumentation(doc="Use FILE as the GC content bias profile.  This profile will\nadjust the read coverage based on the GC content of\nfragments.  Defaults:\n/usr/local/share/pirs/GC-depth_Profiles/humNew.gcdep_100.dat,\n/usr/local/share/pirs/GC-depth_Profiles/humNew.gcdep_150.dat,\n/usr/local/share/pirs/GC-depth_Profiles/humNew.gcdep_200.dat,\ndepending on the mean insert length.")), ToolInput(tag="in_subst_error_rate", input_type=File(optional=True), prefix="--subst-error-rate", doc=InputDocumentation(doc="Set the substitution error rate.  The base-calling profile\nwill still be used, but the average frequency of errors will\nbe changed to RATE.  Set to 0 to disable substitution errors\ncompletely.  In that case, the base-calling profile will not\nbe used.  Default: default error rate of base-calling\nprofile.\nNote: since pIRS parameterizes the error rate by\nseveral parameters, it is very difficult to determine exactly\nwhat needs to be done to make the error rate be a given\nvalue.  We try to adjust the probabilities of getting each\nquality score in order to accomodate the user-supplied error\nrate.  However, depending on your input sequences, the actual\nerror rate simulated by pIRS could be off by 20% or more.\nPlease check the informational output to see the final error\nrate that was actually simulated.")), ToolInput(tag="in_substitution_error_algorithm", input_type=String(optional=True), prefix="--substitution-error-algorithm", doc=InputDocumentation(doc="Set the algorithm used for simulating substitition errors.\nIt may be set to the string 'dist' or 'qtrans'.  The\ndefault is 'qtrans'.\nThe 'dist' algorithm looks up the substitution error rate\nfor each base pair based on the current cycle and the true\nbase.  This lookup produces a quality score and a called base\nthat may or may not be the same as the true base.  In the\nbase-calling profile, the matrix we use is marked as the\n[DistMatrix].\nThe 'qtrans' algorithm is a Markov-chain model based on the\nprevious quality score and current cycle.  The next quality\nscore is looked up with a certain probability based on these\nparameters.  The matrix used for this is marked as\n[QTransMatrix] in the base-calling profile. Then, the the\nDistMatrix is used to find a called base for the quality score.\nThe DistMatrix is also used to call the base in the first\ncycle.")), ToolInput(tag="in_ea_mss", input_type=String(optional=True), prefix="--eamss", doc=InputDocumentation(doc="Use the EAMSS algorithm for masking read quality.  MODE may be\nthe string 'quality' or 'lowercase'.  The EAMSS algorithm\nidentifies low-quality, GC-rich regions near the ends of reads.\n'quality' mode will change the quality scores on these\nregions to (2 + quality_shift), while 'lowercase' mode\nwill change the base pairs to lower case, but not change\nthe quality values.  Default: Do not use EAMSS.")), ToolInput(tag="in_quality_shift", input_type=Int(optional=True), prefix="--quality-shift", doc=InputDocumentation(doc="Set the ASCII shift of the quality value (usually 64 or 33 for\nIllumina data).  Default: 33")), ToolInput(tag="in_no_quality_values", input_type=Boolean(optional=True), prefix="--no-quality-values", doc=InputDocumentation(doc="Do not simulate quality values.  The simulated reads will be\nwritten as a FASTA file rather than a FASTQ file.\nSubstitution errors may still be done; if you do not want\nto simulate any substition errors, provide --error-rate=0 or\n--no-substitution-errors.")), ToolInput(tag="in_no_substitution_errors", input_type=Boolean(optional=True), prefix="--no-substitution-errors", doc=InputDocumentation(doc="Do not simulate substitution errors.  Equivalent to\n--error-rate=0.")), ToolInput(tag="in_no_in_del_errors", input_type=Boolean(optional=True), prefix="--no-indel-errors", doc=InputDocumentation(doc="Do not simulate indels.  The indel error profile will not be\nused.")), ToolInput(tag="in_no_gc_content_bias", input_type=Boolean(optional=True), prefix="--no-gc-content-bias", doc=InputDocumentation(doc="Do not simulate GC bias.  The GC bias profile will not be\nused.")), ToolInput(tag="in_output_prefix", input_type=String(optional=True), prefix="--output-prefix", doc=InputDocumentation(doc="Use PREFIX as the prefix of the output files.  Default:\n'pirs_reads'")), ToolInput(tag="in_output_file_type", input_type=File(optional=True), prefix="--output-file-type", doc=InputDocumentation(doc="The string 'text' or 'gzip' to specify the type of\nthe output FASTQ files containing the simulated reads\nof the genome, as well as the log files.  Default: 'text'")), ToolInput(tag="in_compress", input_type=Boolean(optional=True), prefix="--compress", doc=InputDocumentation(doc="Equivalent to -c gzip.")), ToolInput(tag="in_no_log_files", input_type=Boolean(optional=True), prefix="--no-log-files", doc=InputDocumentation(doc="Do not write the log files.")), ToolInput(tag="in_random_seed", input_type=Int(optional=True), prefix="--random-seed", doc=InputDocumentation(doc="Use SEED as the random seed. Default:\ntime(NULL) * getpid().  Note: If pIRS was not compiled with\n--disable-threads, each thread actually uses its own random\nnumber generator that is seeded by this base seed added to\nthe thread number; also, if you need pIRS's output to be\nexactly reproducible, you must specify the random seed as well\nas use only 1 simulator thread (--threads=1, or configure\nwith --disable-threads, or run on system with 4 or fewer\nprocessors).")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Use NUM_THREADS threads to simulate reads.  This option is\nnot available if pIRS was compiled with the --disable-threads\noption.  Default: number of processors minus 2 if writing\nuncompressed output, or number of processors minus 3 if\nwriting compressed output, or 1 if there are not this many\nprocessors.")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Do not print informational messages."))], outputs=[ToolOutput(tag="out_output_file_type", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_file_type", type_hint=File()), doc=OutputDocumentation(doc="The string 'text' or 'gzip' to specify the type of\nthe output FASTQ files containing the simulated reads\nof the genome, as well as the log files.  Default: 'text'"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Pirs_Simulate_V0_1_0().translate("wdl", allow_empty_container=True)

